
# Type: slot_definition_is_a




URI: [meta:slot_definition_is_a](https://w3id.org/biolink/biolinkml/meta/slot_definition_is_a)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [SlotDefinition](SlotDefinition.md)

## Parents

 *  is_a: [is_a](is_a.md)

## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
